@@ -7,13 +7,10 @@ HUNT_SHOWDOWN_TEST_SERVER_APP_ID: int = 770720  # Hunt: Showdown (Test Server) A
 WORKING_DIRECTORY: str = os.getcwd()
 RESOURCES_PATH: str = os.path.realpath(os.path.join(WORKING_DIRECTORY, "resources"))
 MATCH_LOGS_PATH: str = os.path.join(RESOURCES_PATH, "logs")
-os.makedirs(name=RESOURCES_PATH, exist_ok=True)  # Create the resource directory if it doesn't exist
-os.makedirs(name=MATCH_LOGS_PATH, exist_ok=True)  # Create the MATCH LOGS directory if it doesn't exist
 
 # Steam
 STEAMWORKS_BINARIES_PATH: str = os.path.join(RESOURCES_PATH, "steam")
 STEAMWORKS_SDK_PATH: str = os.path.join(STEAMWORKS_BINARIES_PATH, "steamworks_sdk.zip")
-os.makedirs(name=STEAMWORKS_BINARIES_PATH, exist_ok=True)  # Create the bin directory if it doesn't exist
 
 # Formatting
 STAR_SYMBOL: str = "★"
@@ -30,10 +27,11 @@ def _create_table_helper(table_name: str, fields: tuple[str, ...]) -> str:
 
 
 # Tables
-_PLAYER_LOG_COLUMNS = ("id INTEGER PRIMARY KEY",
-                       "profile_id INTEGER UNIQUE", "name TEXT NOT NULL", "mmr INTEGER DEFAULT 0 NOT NULL",
-                       "kills INTEGER DEFAULT 0 NOT NULL", "deaths INTEGER DEFAULT 0 NOT NULL",
-                       "encounters INTEGER DEFAULT 0 NOT NULL")
+_PLAYER_LOG_COLUMNS: tuple[str, ...] = ("id INTEGER PRIMARY KEY",
+                                        "profile_id INTEGER UNIQUE",
+                                        "name TEXT NOT NULL", "mmr INTEGER DEFAULT 0 NOT NULL",
+                                        "kills INTEGER DEFAULT 0 NOT NULL", "deaths INTEGER DEFAULT 0 NOT NULL",
+                                        "encounters INTEGER DEFAULT 0 NOT NULL")
 DATABASE_TABLE_QUERIES: tuple[str, ...] = (
     _create_table_helper("data_hashes", ("id INTEGER PRIMARY KEY", "hash varchar(64) UNIQUE", "path TEXT NOT NULL")),
     _create_table_helper("player_log_bountyhunt", _PLAYER_LOG_COLUMNS),
